##################################
F.W. Bell 5080 Handheld Gaussmeter
##################################

.. autoclass:: pymeasure.instruments.fwbell.FWBell5080
    :members:
    :show-inheritance:
    :inherited-members: CommonBase
